==> kibana-7.5.2-1-any.pkg.tar.zst: usr/share/kibana/src/legacy/core_plugins/timelion/public/directives/timelion_grid.js <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import $ from 'jquery';

const app = require('ui/modules').get('apps/timelion', []);
app.directive('timelionGrid', function() {
  return {
    restrict: 'A',
    scope: {
      timelionGridRows: '=',
      timelionGridColumns: '=',
    },
    link: function($scope, $elem) {
      function init() {
        setDimensions();
      }

      $scope.$on('$destroy', function() {
        $(window).off('resize'); //remove the handler added earlier
      });

      $(window).resize(function() {
        setDimensions();
      });

      $scope.$watchMulti(['timelionGridColumns', 'timelionGridRows'], function() {
        setDimensions();
      });

      function setDimensions() {
        const borderSize = 2;
        const headerSize = 45 + 35 + 28 + 20 * 2; // chrome + subnav + buttons + (container padding)
        const verticalPadding = 10;

        if ($scope.timelionGridColumns != null) {
          $elem.width($elem.parent().width() / $scope.timelionGridColumns - borderSize * 2);
        }

        if ($scope.timelionGridRows != null) {
          $elem.height(
            ($(window).height() - headerSize) / $scope.timelionGridRows -
              (verticalPadding + borderSize * 2)
          );
        }
      }

      init();
    },
  };
});

==> kibana-7.9.2-1-any.pkg.tar.zst: usr/share/kibana/src/legacy/core_plugins/timelion/public/directives/timelion_grid.js <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import $ from 'jquery';
import { uiModules } from 'ui/modules';

const app = uiModules.get('apps/timelion', []);
app.directive('timelionGrid', function () {
  return {
    restrict: 'A',
    scope: {
      timelionGridRows: '=',
      timelionGridColumns: '=',
    },
    link: function ($scope, $elem) {
      function init() {
        setDimensions();
      }

      $scope.$on('$destroy', function () {
        $(window).off('resize'); //remove the handler added earlier
      });

      $(window).resize(function () {
        setDimensions();
      });

      $scope.$watchMulti(['timelionGridColumns', 'timelionGridRows'], function () {
        setDimensions();
      });

      function setDimensions() {
        const borderSize = 2;
        const headerSize = 45 + 35 + 28 + 20 * 2; // chrome + subnav + buttons + (container padding)
        const verticalPadding = 10;

        if ($scope.timelionGridColumns != null) {
          $elem.width($elem.parent().width() / $scope.timelionGridColumns - borderSize * 2);
        }

        if ($scope.timelionGridRows != null) {
          $elem.height(
            ($(window).height() - headerSize) / $scope.timelionGridRows -
              (verticalPadding + borderSize * 2)
          );
        }
      }

      init();
    },
  };
});
